@@ -5,7 +5,7 @@ from simpletrainer.components.basic.file_handler import FileHandler
 from simpletrainer.components.basic.metric_tracker import MetricTracker
 from simpletrainer.components.basic.model_watcher import ModelWatcher
 from simpletrainer.components.basic.save_best_model import SaveBestModel
-from simpletrainer.components.basic.save_trainer_info import SaveTrainerInfo
+from simpletrainer.components.basic.save_checkpoint import SaveCheckpoint
 from simpletrainer.components.basic.scaler_monitor import ScalerMonitor
 from simpletrainer.components.basic.timer import Timer
 
@@ -17,5 +17,5 @@ __all__ = [
     'ScalerMonitor',
     'Timer',
     'ModelWatcher',
-    'SaveTrainerInfo',
+    'SaveCheckpoint',
 ]
